# monoshape

This program takes an image that has well differentiated light and dark tones and extracts its monochromatic shape in the desired colour with a transparent background.

![Use demonstration](docs/demo.png?raw=true "Use demonstration")


## To set up

You can use Homebrew to install this program via my tap repository:

```
$ brew install glezseoane/homebrew-tap/monoshape
```

You also can use PyPI to install this program:

```
$ pip install monoshape
```

Alternative, clone and go to this repository home directory, and then run:

```
$ python setup.py install
```

Both methods install last **monoshape** stable version on your machine.


<br>

Read the man of this tool to known more about its use.

> Note about man pages: if you use `pip` method to install this program, assert that man directories of your python environment are added to your `MANPATH` to can get this program's man pages with the `man` command. Python might install man pages in default machine level directories.

